==> tuna-gateway-0.0.6.tgz: package/src/dom/piece.js <==
import TunaErrorHandler from "../infra/tunaErrorHandler.js";

export default class Piece {

    constructor(place, id, type, opts, component, validationFunction, group) {
        this.place = place;
        this.id = id;
        this.type = type;
        this.opts = opts;
        this.component = component;
        this.validationFunction = validationFunction;
        this.group = group;
        this.isEnabled = true;
    }

    isEnabled(){
        return this.isEnabled;
    }

    getId() {
        return this.id;
    }

    getPlace() {
        return this.place;
    }

    getGroup() {
        return this.group;
    }

    clear() {
        return this.component.clear();
    }

    changeEnableStatus(enabled) {
        this.isEnabled = enabled;
        if (this.component.changeEnableStatus)
            this.component.changeEnableStatus(this.isEnabled);
        else{
            this.component.state.disabled = !this.isEnabled;
            this.updateComponent();
        }
    }

    unmountComponent(preserveRoot) {
        this.component.unmount(preserveRoot);
    }

    getValidationFunction() {
        return this.validationFunction;
    }

    getValue() {
        let value;
        try {
            this.resetInvalidMarkup();
            value = this.component.getValue();

            if(value === null && !this.isEnabled)
                return null;

            if (value && typeof value === "string" && this.opts.cleanMask)
                value = value.replace(/[^\da-zA-Z]/g, '');

            if (this.validationFunction) {
                if (this.validationFunction(value))
                    return value;
                else {
                    this.markAsInvalid();
                    throw new TunaErrorHandler("ERR:07", { fieldNames: this.type.name });
                }
            }
            return value;
        } catch (e) {
            this.markAsInvalid();
            throw e;
        }
    }

    setValue(value) {
        this.component.setValue(value);
        this.component.update();
    }

    getPropertyName() {
        return this.type.propertyName;
    }

    getOptions() {
        return this.opts;
    }

    markAsInvalid() {
        this.component.state.showValidationMessage = true;
        this.updateComponent();
        this.component.focus();
    }

    resetInvalidMarkup() {
        this.component.state.showValidationMessage = false;
        this.updateComponent();
    }

    updateComponent() {
        this.component.update();
    }

    getType() {
        return this.type;
    }
}

==> tuna-gateway-1.0.4.tgz: package/src/dom/piece.js <==
import TunaErrorHandler from "../infra/tunaErrorHandler.js";

export default class Piece {

    constructor(place, id, type, opts, component, validationFunction, group) {
        this.place = place;
        this.id = id;
        this.type = type;
        this.opts = opts;
        this.component = component;
        this.validationFunction = validationFunction;
        this.group = group;
        this.isEnabled = true;
    }

    getId = _ => this.id;
    getPlace = _ => this.place;
    getGroup = _ => this.group;
    clear = _ => this.component.clear();
    unmountComponent = preserveRoot => this.component.unmount(preserveRoot);
    getValidationFunction = _ => this.validationFunction;
    getPropertyName = _ => this.type.propertyName;
    getOptions = _ => this.opts;
    updateComponent = _ => this.component.update();
    getType = _ => this.type;

    changeEnableStatus(enabled) {
        this.isEnabled = enabled;
        if (this.component.changeEnableStatus)
            this.component.changeEnableStatus(this.isEnabled);
        else {
            this.component.state.disabled = !this.isEnabled;
            this.updateComponent();
        }
    }

    getValue() {
        let value;
        try {
            this.resetInvalidMarkup();
            value = this.component.getValue();

            if (value === null && !this.isEnabled)
                return null;

            if (value && typeof value === "string" && this.opts.cleanMask)
                value = value.replace(/[^\da-zA-Z]/g, '');

            if (this.validationFunction) {
                if (this.validationFunction(value))
                    return value;
                else {
                    this.markAsInvalid();
                    throw new TunaErrorHandler("ERR:07", { fieldNames: this.type.name });
                }
            }
            return value;
        } catch (e) {
            this.markAsInvalid();
            throw e;
        }
    }

    setValue(value) {
        this.component.setValue(value);
        this.component.update();
    }

    markAsInvalid() {
        this.component.state.showValidationMessage = true;
        this.updateComponent();
        this.component.focus();
    }

    resetInvalidMarkup() {
        this.component.state.showValidationMessage = false;
        this.updateComponent();
    }
}
